2005 Tribute - Mazda Forum
Description: Hi All, My wife's 2005 Tribute with 102k miles on it has exhibited a slight hesitation when accelerating at around 20mph. We recently had the truck
Keywords: 2005,Tribute, 2005 Tribute, mazda forum, mazda forums, mazda tech, mazda technical forum, used mazda car, mazda car forum, mazda van forum, mazdaspeed forum, mazda cx9 forum, mazda protege forum, mazda miata forum, mazda 2 forum, mazda cx7 forum

Facebook Remember Me?
Reply

Page 1 of 3 | 1 | 2 | 3 |

Tweet

| LinkBack | Thread Tools

post #1 of 23 (permalink) Old 04-25-2015, 09:47 PM Thread Starter
tate16t
Junior Member
Join Date: Jan 2005
Posts: 26
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 0 Post(s)
2005 Tribute

Hi All,
My wife's 2005 Tribute with 102k miles on it has exhibited a slight hesitation when accelerating at around 20mph. We recently had the truck tuned up. Has anyone experience anything like this? I see mention of a dirty throttle body when searching google. Any ideas?
Thanks
tate16t is offline
Quote Quick Reply

Remove Advertisements Sponsored Links
Mazda World Advertisement |

post #2 of 23 (permalink) Old 04-26-2015, 01:55 PM
oppo
MazdaWorld Member
Join Date: Feb 2012
Posts: 50
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 8 Post(s)
I've had the same issue with both of our Tributes. Cleaning the Throttle Body is a must. I recommend removing the body, spend some time with it and clean very well, especially at the butterfly. Have new gaskets on hand for installation. Don't skip this, if the old seals have failed it can cause problems. Next, Replace the IAC valve. This is located on top of the engine held on with 2 bolts.(chrome color) If it has never been changed then now is the time. (I've tried cleaning them, but that has never worked for me) They are easy to do and not that expensive. About $35.00. (In fact, do this first and see what happens, it may be the fix you need) Then, Clean the MAF sensor elements using MAF cleaner. The sensor is located in the air intake manifold just after the air cleaner. Do not remove the sensor itself but the housing and spray the cleaner over the sensor element. Also, run a tank full of techron 3 or 4 times a year it will help keep the system clean. Remember to only run Regular (87) gas. These cars do not like the higher octane, Also, do not add octane booster. Do a scan of the PCM and be sure there are no hidden error codes. At 100,00 miles I would replace the manifold seals and all the coil packs but that's just me. I did that on our 2003 and that one is full of Zoom. My 2004 has new packs and seals also full of zoom. However, The rear seals are a tough job, the fronts not too bad. The coil packs are not hard to change. Shop the net for best prices. I did a set of 6 for under $100.00 about 1 year ago. Good Luck!
oppo is offline
Quote Quick Reply
post #3 of 23 (permalink) Old 04-26-2015, 08:41 PM Thread Starter
tate16t
Junior Member
Join Date: Jan 2005
Posts: 26
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 0 Post(s)
Quote:
Originally Posted by oppo View Post
I've had the same issue with both of our Tributes. Cleaning the Throttle Body is a must. I recommend removing the body, spend some time with it and clean very well, especially at the butterfly. Have new gaskets on hand for installation. Don't skip this, if the old seals have failed it can cause problems. Next, Replace the IAC valve. This is located on top of the engine held on with 2 bolts.(chrome color) If it has never been changed then now is the time. (I've tried cleaning them, but that has never worked for me) They are easy to do and not that expensive. About $35.00. (In fact, do this first and see what happens, it may be the fix you need) Then, Clean the MAF sensor elements using MAF cleaner. The sensor is located in the air intake manifold just after the air cleaner. Do not remove the sensor itself but the housing and spray the cleaner over the sensor element. Also, run a tank full of techron 3 or 4 times a year it will help keep the system clean. Remember to only run Regular (87) gas. These cars do not like the higher octane, Also, do not add octane booster. Do a scan of the PCM and be sure there are no hidden error codes. At 100,00 miles I would replace the manifold seals and all the coil packs but that's just me. I did that on our 2003 and that one is full of Zoom. My 2004 has new packs and seals also full of zoom. However, The rear seals are a tough job, the fronts not too bad. The coil packs are not hard to change. Shop the net for best prices. I did a set of 6 for under $100.00 about 1 year ago. Good Luck!
Thanks for this. Any instructions or videos you could provide would be great.
tate16t is offline
Quote Quick Reply
post #4 of 23 (permalink) Old 04-26-2015, 09:11 PM
oppo
MazdaWorld Member
Join Date: Feb 2012
Posts: 50
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 8 Post(s)
Unfortunately I have no video or picks. I always mean to take them, but I get so involved so fast that I just don't. If you tell me what you want to do first ( I recommend the IAC replacement) I will go out to my 2004 Tribute and take some picks for you. As far as the more involved jobs, let me know what it is and I will try to provide some step by step. I'll do my best to check back here as much as possible so as not to leave you hanging. I will say, If your kinda new to auto repair or just new to the Tribute, I advise to pick up the Chiltons manual for Ford Escape, Tribute and Mariner. It's not the best but it helps. I found mine at Orileys Auto Parts. (about $20.00, if memory serves).

Last edited by oppo; 04-26-2015 at 09:32 PM.
oppo is offline
Quote Quick Reply
post #5 of 23 (permalink) Old 04-26-2015, 09:23 PM
oppo
MazdaWorld Member
Join Date: Feb 2012
Posts: 50
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 8 Post(s)
I forgot to ask. Is your 2005 a Hybrid, V6 or 4 banger? Automatic? DX, LX or EX or ? Also, A photo of your engine will help. Thanks!
oppo is offline
Quote Quick Reply
post #6 of 23 (permalink) Old 04-27-2015, 06:12 PM
oppo
MazdaWorld Member
Join Date: Feb 2012
Posts: 50
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 8 Post(s)
I found a youtube link that shows how to replace the IAC valve. The video is on a Ford Escape but it's the same for our Tributes. Hope it helps.
https://www.youtube.com/watch?v=0liDtBLIu-4
oppo is offline
Quote Quick Reply
post #7 of 23 (permalink) Old 04-30-2015, 08:58 AM Thread Starter
tate16t
Junior Member
Join Date: Jan 2005
Posts: 26
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 0 Post(s)
Quote:
Originally Posted by oppo View Post
I forgot to ask. Is your 2005 a Hybrid, V6 or 4 banger? Automatic? DX, LX or EX or ? Also, A photo of your engine will help. Thanks!
It's a v6 DX.

Last edited by tate16t; 04-30-2015 at 09:31 AM.
tate16t is offline
Quote Quick Reply
post #8 of 23 (permalink) Old 04-30-2015, 09:30 AM Thread Starter
tate16t
Junior Member
Join Date: Jan 2005
Posts: 26
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 0 Post(s)
Quote:
Originally Posted by oppo View Post
I found a youtube link that shows how to replace the IAC valve. The video is on a Ford Escape but it's the same for our Tributes. Hope it helps.
https://www.youtube.com/watch?v=0liDtBLIu-4
Looks simple enough. I will try this.
tate16t is offline
Quote Quick Reply
post #9 of 23 (permalink) Old 04-30-2015, 09:34 AM Thread Starter
tate16t
Junior Member
Join Date: Jan 2005
Posts: 26
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 0 Post(s)
Here are some photos of the engine.
Attached Thumbnails
tate16t is offline
Quote Quick Reply
post #10 of 23 (permalink) Old 04-30-2015, 03:57 PM
oppo
MazdaWorld Member
Join Date: Feb 2012
Posts: 50
Mentioned: 0 Post(s)
Tagged: 0 Thread(s)
Quoted: 8 Post(s)
Thanks for the Pics. I wanted to be sure the engines were the same for 2005. Mine are a 2003 and a 2004. Very similar. I found this link for coil packs in case your interested.
Ford, Mazda, & Mercury Ignition Coils | Araparts® (916) 585-6835
Let me know how it's going!
oppo is offline
Quote Quick Reply

Remove Advertisements Sponsored Links
Mazda World Advertisement |

Reply |
Page 1 of 3 | 1 | 2 | 3 |

Gear in this thread - Powered by O'Reilly Auto Parts

- PlastiColor - Key Chain
  Key Chain - Darth Vader Key Chain
  More on PlastiColor - Key Chain
- Purple Power - Cleaner/Degreaser
  Cleaner/Degreaser - Industrial Strength; 2.5 Gallon
  More on Purple Power - Cleaner/Degreaser
- PlastiColor - Key Chain
  Key Chain - Storm Trooper Key Chain
  More on PlastiColor - Key Chain

vBulletin Message
Cancel Changes

Quick Reply
The following errors occurred with your submission
Okay
Message: Options Quote message in reply?
## Register Now In order to be able to post messages on the Mazda Forum forums, you must first register. Please enter your desired user name, your email address and other required details in the form below. User Name: Password
Please enter a password for your user account. Note that passwords are case-sensitive.
Password:
Confirm Password:
Email Address
Please enter a valid email address for yourself.
Email Address: |
| OR | ## Log-in
User Name |
Password |
Remember Me? |
Human Verification In order to verify that you are a human and not a spam bot, please enter the answer into the following box below based on the instructions contained in the graphic. Posting Quick Reply - Please Wait Posting Quick Reply - Please Wait

« Previous Thread | Next Thread

User Tag List

Thread Tools
Show Printable Version Show Printable Version Email this Page Email this Page

Posting Rules |
You may post new threads You may post replies You may not post attachments You may not edit your posts BB code is On Smilies are On [IMG] code is On HTML code is Off Trackbacks are On Pingbacks are On Refbacks are On Forum Rules

For the best viewing experience please update your browser to Google Chrome

Terms of Use